@@ -1,9 +1,9 @@
 package App::CSelUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-29'; # DATE
+our $DATE = '2021-02-19'; # DATE
 our $DIST = 'App-CSelUtils'; # DIST
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.087'; # VERSION
 
 use 5.010001;
 use strict;
@@ -430,7 +430,7 @@ App::CSelUtils - Utilities related to Data::CSel
 
 =head1 VERSION
 
-This document describes version 0.086 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2020-04-29.
+This document describes version 0.087 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2021-02-19.
 
 =head1 DESCRIPTION
 
@@ -603,7 +603,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-CSelUtils>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-CSelUtils>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-CSelUtils/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -619,7 +619,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
